pending_moves

Function pending_moves 

async fn pending_moves(
    conn: &mut PgConnection,
    scope: &RegistrationScope,
    limit: i64,
) -> ModelResult<Vec<PendingMove>>
Only the rows whose facts disagree with the state they are in, so limit cannot be spent on rows that need nothing.